pub fn parse_key(input: &str) -> Result<KeyChord, ParseError>Expand description
Parse exactly one chord. Errors if the input parses to zero chords or more than one.
pub fn parse_key(input: &str) -> Result<KeyChord, ParseError>Parse exactly one chord. Errors if the input parses to zero chords or more than one.